[Datatype-cvs] tools/dtdriver/decoder/audio adecoder.cpp, 1.18.10.2, 1.18.10.3

[Datatype-cvs] tools/dtdriver/decoder/audio adecoder.cpp, 1.18.10.2, 1.18.10.3

pbasic at helixcommunity.org pbasic at helixcommunity.org
Tue May 6 03:19:14 PDT 2008


Update of /cvsroot/datatype/tools/dtdriver/decoder/audio
In directory cvs.internal.helixcommunity.org:/tmp/cvs-serv4154/audio

Modified Files:
      Tag: hxclient_3_1_0_atlas
	adecoder.cpp 
Log Message:
Enabled transfer of known metadata when using DecodeSource!=0.

Index: adecoder.cpp
===================================================================
RCS file: /cvsroot/datatype/tools/dtdriver/decoder/audio/adecoder.cpp,v
retrieving revision 1.18.10.2
retrieving revision 1.18.10.3
diff -u -d -r1.18.10.2 -r1.18.10.3
--- adecoder.cpp	25 Apr 2008 08:25:44 -0000	1.18.10.2
+++ adecoder.cpp	6 May 2008 10:19:11 -0000	1.18.10.3
@@ -1732,16 +1732,19 @@
                 // 2) See if present in STREAM header
                 // 3) See if renderer knows this property
                 // 4) See if present in stats (to be implemented later)
-                SetSourcePropertyCString(m_pStreamHeaderOut, "SrcCodec");
-                SetSourcePropertyCString(m_pStreamHeaderOut, "SrcInterleaver");
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcBitRate");
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcVBREnabled");
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcVBRQuality");
-//                SetSourcePropertyCString(m_pStreamHeaderOut, "SrcInterleaved"); // not sure about this one
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcSamplesPerSecond");
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcBitsPerSample");
-                SetSourcePropertyULONG32(m_pStreamHeaderOut, "SrcNumChannels");
+                SetSourcePropertyCString(rpValues, "SrcCodec");
+                SetSourcePropertyCString(rpValues, "SrcInterleaver");
+                SetSourcePropertyULONG32(rpValues, "SrcBitRate");
+                SetSourcePropertyULONG32(rpValues, "SrcVBREnabled");
+                SetSourcePropertyULONG32(rpValues, "SrcVBRQuality");
+//                SetSourcePropertyCString(rpValues, "SrcInterleaved"); // not sure about this one
+                SetSourcePropertyULONG32(rpValues, "SrcSamplesPerSecond");
+                SetSourcePropertyULONG32(rpValues, "SrcBitsPerSample");
+                SetSourcePropertyULONG32(rpValues, "SrcNumChannels");
             }
+
+            // Transfer metadata if present
+            CopyKnownHeaderMetaData(rpValues, m_pStreamHeaderIn);
         }
     }
 




More information about the Datatype-cvs mailing list
 

Site Map   |   Terms of Use   |   Privacy Policy   |   Contact Us

Copyright © 1995-2007 RealNetworks, Inc. All rights reserved. RealNetworks and Helix are trademarks of RealNetworks.
All other trademarks or registered trademarks are the property of their respective holders.